Skip to contents

Professional EKIO branding and styling for gt table objects.

Usage

gt_theme_ekio(
  data,
  table_width = "100%",
  font_size = 14,
  stripe = TRUE,
  add_footer = TRUE,
  font_title = NULL,
  font_body = NULL,
  font_numeric = NULL,
  font_labels = NULL
)

Arguments

data

A gt table object

table_width

Character. Width of the table (default: "100%")

font_size

Numeric. Base font size in pixels (default: 14)

stripe

Logical. Apply alternating row striping (default: TRUE)

Logical. Add automatic EKIO footer (default: TRUE)

font_title, font_body, font_numeric, font_labels

A font family or registry key (lora, lato, georgia, roboto_slab, fira_code, host_grotesk). NULL uses the corresponding ekiotable.font_<role> option. Title and body then use ekioplot.font_title and ekioplot.font_text, respectively, before falling back to Lora and Lato. Numeric and label fonts inherit the resolved body font unless explicitly set or configured through their role option. Fonts must be available to the renderer; this function does not install them.

Value

A styled gt table object

Examples

library(gt)
#> Warning: package ‘gt’ was built under R version 4.5.2
head(mtcars, 10) |>
  gt() |>
  gt_theme_ekio()
mpg cyl disp hp drat wt qsec vs am gear carb
21.0 6 160.0 110 3.90 2.620 16.46 0 1 4 4
21.0 6 160.0 110 3.90 2.875 17.02 0 1 4 4
22.8 4 108.0 93 3.85 2.320 18.61 1 1 4 1
21.4 6 258.0 110 3.08 3.215 19.44 1 0 3 1
18.7 8 360.0 175 3.15 3.440 17.02 0 0 3 2
18.1 6 225.0 105 2.76 3.460 20.22 1 0 3 1
14.3 8 360.0 245 3.21 3.570 15.84 0 0 3 4
24.4 4 146.7 62 3.69 3.190 20.00 1 0 4 2
22.8 4 140.8 95 3.92 3.150 22.90 1 0 4 2
19.2 6 167.6 123 3.92 3.440 18.30 1 0 4 4
EKIO